import React, { createContext, useEffect, useRef, useState } from 'react';
import ReactDom from 'react-dom';
import { BrowserRouter, Navigate, Route, Routes } from 'react-router-dom';
import { Gallery, DocumentAbout, LoginPage, NotFoundPage, ProfilePage, DifferencePage, SettingPage, ReaderPage } from './page/mod';
import { getInitialValue, UserContext } from './state';
import { ThemeProvider, createTheme } from '@mui/material';

import './css/style.css';

const theme = createTheme();

const App = () => {
    const [user, setUser] = useState("");
    const [userPermission, setUserPermission] = useState<string[]>([]);
    (async () => {
        const { username, permission } = await getInitialValue();
        if (username !== user) {
            setUser(username);
            setUserPermission(permission);
        }
    })();
    //useEffect(()=>{});
    return (
        <UserContext.Provider value={{
            username: user,
            setUsername: setUser,
            permission: userPermission,
            setPermission: setUserPermission
        }}>
            <ThemeProvider theme={theme}>
                <BrowserRouter>
                    <Routes>
                        <Route path="/" element={<Navigate replace to='/search?' />} />
                        <Route path="/search" element={<Gallery />} />
                        <Route path="/doc/:id" element={<DocumentAbout />}></Route>
                        <Route path="/doc/:id/reader" element={<ReaderPage />}></Route>
                        <Route path="/login" element={<LoginPage></LoginPage>} />
                        <Route path="/profile" element={<ProfilePage />}></Route>
                        <Route path="/difference" element={<DifferencePage />}></Route>
                        <Route path="/setting" element={<SettingPage />}></Route>
                        <Route path="*" element={<NotFoundPage />} />
                    </Routes>
                </BrowserRouter>
            </ThemeProvider>
        </UserContext.Provider>);
};

ReactDom.render(
    <App />,
    document.getElementById("root")
);